==> ejc-ztpccom-api-3.0.0-20230715.090459-37-sources.jar: com/ejianc/business/ztpc/billcode/bean/BillCodeRuleApiVO.java <==
package com.ejianc.business.ztpc.billcode.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;


/**
 * 取号编码规则
 * 
 * @author generator
 * 
 */
public class BillCodeRuleApiVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目id
    private Long categoryId; // 文档分类主键Id
    private String ruleType; // 规则类型，0内部编码，1外部编码

    private Long sourcePid; // 来源单据主表id
    private String sourceCode; // 来源单据编码
    private String sourceType; // 来源单据类型

    private String rule05; // 专业字段对应的code，对应数据字典档案编码
    private String rule07; // 预留字段
    private String rule08; // 预留字段
    private String rule09; // 预留字段
    private String rule10; // 预留字段
    private String rule11; // 预留字段
    private String rule12; // 预留字段
    private String rule13; // 预留字段
    private String rule14; // 预留字段
    private String rule15; // 预留字段
    private String rule16; // 预留字段
    private String rule17; // 预留字段
    private String rule18; // 预留字段
    private String rule19; // 预留字段
    private String rule20; // 预留字段
    private String rule21; // 预留字段
    private String rule22; // 预留字段
    private String rule23; // 预留字段
    private String rule24; // 预留字段
    private String rule25; // 预留字段

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getRuleType() {
        return ruleType;
    }

    public void setRuleType(String ruleType) {
        this.ruleType = ruleType;
    }

    public Long getSourcePid() {
        return sourcePid;
    }

    public void setSourcePid(Long sourcePid) {
        this.sourcePid = sourcePid;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getRule05() {
        return rule05;
    }

    public void setRule05(String rule05) {
        this.rule05 = rule05;
    }

    public String getRule07() {
        return rule07;
    }

    public void setRule07(String rule07) {
        this.rule07 = rule07;
    }

    public String getRule08() {
        return rule08;
    }

    public void setRule08(String rule08) {
        this.rule08 = rule08;
    }

    public String getRule09() {
        return rule09;
    }

    public void setRule09(String rule09) {
        this.rule09 = rule09;
    }

    public String getRule10() {
        return rule10;
    }

    public void setRule10(String rule10) {
        this.rule10 = rule10;
    }

    public String getRule11() {
        return rule11;
    }

    public void setRule11(String rule11) {
        this.rule11 = rule11;
    }

    public String getRule12() {
        return rule12;
    }

    public void setRule12(String rule12) {
        this.rule12 = rule12;
    }

    public String getRule13() {
        return rule13;
    }

    public void setRule13(String rule13) {
        this.rule13 = rule13;
    }

    public String getRule14() {
        return rule14;
    }

    public void setRule14(String rule14) {
        this.rule14 = rule14;
    }

    public String getRule15() {
        return rule15;
    }

    public void setRule15(String rule15) {
        this.rule15 = rule15;
    }

    public String getRule16() {
        return rule16;
    }

    public void setRule16(String rule16) {
        this.rule16 = rule16;
    }

    public String getRule17() {
        return rule17;
    }

    public void setRule17(String rule17) {
        this.rule17 = rule17;
    }

    public String getRule18() {
        return rule18;
    }

    public void setRule18(String rule18) {
        this.rule18 = rule18;
    }

    public String getRule19() {
        return rule19;
    }

    public void setRule19(String rule19) {
        this.rule19 = rule19;
    }

    public String getRule20() {
        return rule20;
    }

    public void setRule20(String rule20) {
        this.rule20 = rule20;
    }

    public String getRule21() {
        return rule21;
    }

    public void setRule21(String rule21) {
        this.rule21 = rule21;
    }

    public String getRule22() {
        return rule22;
    }

    public void setRule22(String rule22) {
        this.rule22 = rule22;
    }

    public String getRule23() {
        return rule23;
    }

    public void setRule23(String rule23) {
        this.rule23 = rule23;
    }

    public String getRule24() {
        return rule24;
    }

    public void setRule24(String rule24) {
        this.rule24 = rule24;
    }

    public String getRule25() {
        return rule25;
    }

    public void setRule25(String rule25) {
        this.rule25 = rule25;
    }

}

==> ejc-ztpccom-api-3.0.0-20230717.144715-55-sources.jar: com/ejianc/business/ztpc/billcode/bean/BillCodeRuleApiVO.java <==
package com.ejianc.business.ztpc.billcode.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;


/**
 * 取号编码规则
 * 
 * @author generator
 * 
 */
public class BillCodeRuleApiVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long categoryId; // 文档分类主键Id
    private String ruleType; // 规则类型，0内部编码，1外部编码

    private Long sourcePid; // 来源单据主表id
    private String sourceCode; // 来源单据编码
    private String sourceType; // 来源单据类型
    private String sourceTypeName;//来源单据类型名称
    private String rule05; // 专业字段对应的code，对应数据字典档案编码
    private String rule06; // 预留字段
    private String rule07; // 预留字段
    private String rule08; // 预留字段
    private String rule09; // 预留字段
    private String rule10; // 预留字段
    private String rule11; // 预留字段
    private String rule12; // 预留字段
    private String rule13; // 预留字段
    private String rule14; // 预留字段
    private String rule15; // 预留字段
    private String rule16; // 预留字段
    private String rule17; // 预留字段
    private String rule18; // 预留字段
    private String rule19; // 预留字段
    private String rule20; // 预留字段
    private String rule21; // 预留字段
    private String rule22; // 预留字段
    private String rule23; // 预留字段
    private String rule24; // 预留字段
    private String rule25; // 预留字段

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getRuleType() {
        return ruleType;
    }

    public void setRuleType(String ruleType) {
        this.ruleType = ruleType;
    }

    public Long getSourcePid() {
        return sourcePid;
    }

    public void setSourcePid(Long sourcePid) {
        this.sourcePid = sourcePid;
    }

    public String getSourceCode() {
        return sourceCode;
    }

    public void setSourceCode(String sourceCode) {
        this.sourceCode = sourceCode;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public String getRule05() {
        return rule05;
    }

    public void setRule05(String rule05) {
        this.rule05 = rule05;
    }

    public String getRule07() {
        return rule07;
    }

    public void setRule07(String rule07) {
        this.rule07 = rule07;
    }

    public String getRule08() {
        return rule08;
    }

    public void setRule08(String rule08) {
        this.rule08 = rule08;
    }

    public String getRule09() {
        return rule09;
    }

    public void setRule09(String rule09) {
        this.rule09 = rule09;
    }

    public String getRule10() {
        return rule10;
    }

    public void setRule10(String rule10) {
        this.rule10 = rule10;
    }

    public String getRule11() {
        return rule11;
    }

    public void setRule11(String rule11) {
        this.rule11 = rule11;
    }

    public String getRule12() {
        return rule12;
    }

    public void setRule12(String rule12) {
        this.rule12 = rule12;
    }

    public String getRule13() {
        return rule13;
    }

    public void setRule13(String rule13) {
        this.rule13 = rule13;
    }

    public String getRule14() {
        return rule14;
    }

    public void setRule14(String rule14) {
        this.rule14 = rule14;
    }

    public String getRule15() {
        return rule15;
    }

    public void setRule15(String rule15) {
        this.rule15 = rule15;
    }

    public String getRule16() {
        return rule16;
    }

    public void setRule16(String rule16) {
        this.rule16 = rule16;
    }

    public String getRule17() {
        return rule17;
    }

    public void setRule17(String rule17) {
        this.rule17 = rule17;
    }

    public String getRule18() {
        return rule18;
    }

    public void setRule18(String rule18) {
        this.rule18 = rule18;
    }

    public String getRule19() {
        return rule19;
    }

    public void setRule19(String rule19) {
        this.rule19 = rule19;
    }

    public String getRule20() {
        return rule20;
    }

    public void setRule20(String rule20) {
        this.rule20 = rule20;
    }

    public String getRule21() {
        return rule21;
    }

    public void setRule21(String rule21) {
        this.rule21 = rule21;
    }

    public String getRule22() {
        return rule22;
    }

    public void setRule22(String rule22) {
        this.rule22 = rule22;
    }

    public String getRule23() {
        return rule23;
    }

    public void setRule23(String rule23) {
        this.rule23 = rule23;
    }

    public String getRule24() {
        return rule24;
    }

    public void setRule24(String rule24) {
        this.rule24 = rule24;
    }

    public String getRule25() {
        return rule25;
    }

    public void setRule25(String rule25) {
        this.rule25 = rule25;
    }

    public String getSourceTypeName() {
        return sourceTypeName;
    }

    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getRule06() {
        return rule06;
    }

    public void setRule06(String rule06) {
        this.rule06 = rule06;
    }
}
